Structs
- Authentication Config
- Handler
Traits
- Interceptor trait
Functions
- Returns the file, or an index of the directory.
- Delete the filename
- Log the request to a file
- Log the request to stdout
- Save the data of the request to the url
- Rewrites / to /index.html
- Appends a suffix to the url